import unittest

import labbook


class GeneralTests(unittest.TestCase):
    def test_basics(self):
        self.assertEqual('result', labbook.a_function_of_mine())
        
        m = labbook.MyClass()
        self.assertEqual('another result', m.a_method_of_mine())



"""
labbook.py

After modifying this file don't forget to modify __init__.py to expose your package's API.
"""


def a_function_of_mine():
    """
    This function returns the string 'result'.
    """
    return 'result'


class MyClass:
    """
    This is a class that should be documented.
    """
    def a_method_of_mine(self):
        """
        Please document public methods as well.
        """
        return 'another result'




"""
This file defines the public API your package exposes.

The reasoning behind this is it allows you to "import os" in mypackage.py
and then when users "import mypackage" they won't be bothered by "os"
appearing in "dir(mypackage)".

If you don't want to explicitly expose everything you can use:
"from mypackage import *"

"""

VERSION = '1.0.0.2'

#from labbook import a_function_of_mine
#from labbook import MyClass



import labbook, sys, os, os.path

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


me = 'Harsha Krishnareddy'
memail = 'c0mpiler@outlook.com'
url = 'http://pypi.python.org/pypi/labbook'

setup (
    name='labbook',
    version=labbook.VERSION,
    zip_safe=True,
    description='Python package to work with labbook',
    long_description=open('README.md','r').read(),
    author=me,
    author_email=memail,
    maintainer=me,
    maintainer_email=memail,
    url=url,
    license='MIT',
    keywords=['template','labbook', 'empty', 'package', 'example'],
    packages=['labbook'],
    download_url=url,
    platforms=['Independant'],
    classifiers = [
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        ],
    test_suite='nose.collector',
    tests_require=['nose'],
    )
